==> fdm-0.9a.tar.gz: fdm-0.9a/log.c <==
/* $Id: log.c,v 1.4 2006/10/04 10:26:33 nicm Exp $ */
/*      $OpenBSD: log.c,v 1.6 2004/07/12 09:22:38 dtucker Exp $ */

/*
 * Copyright (c) 2003, 2004 Henning Brauer <henning@openbsd.org>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF MIND, USE, DATA OR PROFITS, WHETHER
 * IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>

#include <errno.h>
#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <syslog.h>
#include <time.h>
#include <unistd.h>

#include "fdm.h"

int	debug;

void	logit(int, const char *, ...);

void
log_init(int n_debug)
{
	debug = n_debug;

	if (!debug)
		openlog(__progname, LOG_PID | LOG_NDELAY, LOG_MAIL);

	tzset();
}

void printflike2
logit(int pri, const char *fmt, ...)
{
	va_list	ap;

	va_start(ap, fmt);
	vlog(pri, fmt, ap);
	va_end(ap);
}

void
vlog(int pri, const char *fmt, va_list ap)
{
	char	*nfmt;

	if (debug) {
		/* best effort in out of mem situations */
		if (asprintf(&nfmt, "%s\n", fmt) == -1) {
			vfprintf(stderr, fmt, ap);
			fprintf(stderr, "\n");
		} else {
			vfprintf(stderr, nfmt, ap);
			free(nfmt);
		}
		fflush(stderr);
	} else
		vsyslog(pri, fmt, ap);
}


void printflike1
log_warn(const char *emsg, ...)
{
	char	*nfmt;
	va_list	 ap;

	/* best effort to even work in out of memory situations */
	if (emsg == NULL)
		logit(LOG_CRIT, "%s", strerror(errno));
	else {
		va_start(ap, emsg);

		if (asprintf(&nfmt, "%s: %s", emsg, strerror(errno)) == -1) {
			/* we tried it... */
			vlog(LOG_CRIT, emsg, ap);
			logit(LOG_CRIT, "%s", strerror(errno));
		} else {
			vlog(LOG_CRIT, nfmt, ap);
			free(nfmt);
		}
		va_end(ap);
	}
}

void printflike1
log_warnx(const char *emsg, ...)
{
	va_list	ap;

	va_start(ap, emsg);
	vlog(LOG_CRIT, emsg, ap);
	va_end(ap);
}

void printflike1
log_info(const char *emsg, ...)
{
	va_list	ap;

	va_start(ap, emsg);
	vlog(LOG_INFO, emsg, ap);
	va_end(ap);
}

void printflike1
log_debug(const char *emsg, ...)
{
	va_list	ap;

	if (conf.debug > 0) {
		va_start(ap, emsg);
		vlog(LOG_DEBUG, emsg, ap);
		va_end(ap);
	}
}

void printflike1
log_debug2(const char *emsg, ...)
{
	va_list	ap;

	if (conf.debug > 1) {
		va_start(ap, emsg);
		vlog(LOG_DEBUG, emsg, ap);
		va_end(ap);
	}
}

void printflike1
log_debug3(const char *emsg, ...)
{
	va_list	ap;

	if (conf.debug > 2) {
		va_start(ap, emsg);
		vlog(LOG_DEBUG, emsg, ap);
		va_end(ap);
	}
}

__dead void
fatal(const char *emsg)
{
	if (emsg == NULL)
		logit(LOG_CRIT, "fatal: %s", strerror(errno));
	else
		if (errno)
			logit(LOG_CRIT, "fatal: %s: %s",
			    emsg, strerror(errno));
		else
			logit(LOG_CRIT, "fatal: %s", emsg);

	exit(1);
}

__dead void
fatalx(const char *emsg)
{
	errno = 0;
	fatal(emsg);
}

==> fdm_1.1.orig.tar.gz: fdm-1.1/log.c <==
/* $Id: log.c,v 1.7 2007/03/22 18:56:20 nicm Exp $ */
/*      $OpenBSD: log.c,v 1.6 2004/07/12 09:22:38 dtucker Exp $ */

/*
 * Copyright (c) 2003, 2004 Henning Brauer <henning@openbsd.org>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF MIND, USE, DATA OR PROFITS, WHETHER
 * IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>

#include <errno.h>
#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <syslog.h>
#include <time.h>
#include <unistd.h>

#include "fdm.h"

int	debug;

void	logit(int, const char *, ...);

void
log_init(int n_debug)
{
	debug = n_debug;

	if (!debug)
		openlog(__progname, LOG_PID | LOG_NDELAY, LOG_MAIL);

	tzset();
}

void printflike2
logit(int pri, const char *fmt, ...)
{
	va_list	ap;

	va_start(ap, fmt);
	vlog(stderr, pri, fmt, ap);
	va_end(ap);
}

void
vlog(FILE *f, int pri, const char *fmt, va_list ap)
{
	char	*nfmt;

	if (debug) {
		/* best effort in out of mem situations */
		if (asprintf(&nfmt, "%s\n", fmt) == -1) {
			vfprintf(f, fmt, ap);
			fprintf(f, "\n");
		} else {
			vfprintf(f, nfmt, ap);
			free(nfmt);
		}
		fflush(f);
	} else
		vsyslog(pri, fmt, ap);
}


void printflike1
log_warn(const char *emsg, ...)
{
	char	*nfmt;
	va_list	 ap;

	/* best effort to even work in out of memory situations */
	if (emsg == NULL)
		logit(LOG_CRIT, "%s", strerror(errno));
	else {
		va_start(ap, emsg);

		if (asprintf(&nfmt, "%s: %s", emsg, strerror(errno)) == -1) {
			/* we tried it... */
			vlog(stderr, LOG_CRIT, emsg, ap);
			logit(LOG_CRIT, "%s", strerror(errno));
		} else {
			vlog(stderr, LOG_CRIT, nfmt, ap);
			free(nfmt);
		}
		va_end(ap);
	}
}

void printflike1
log_warnx(const char *emsg, ...)
{
	va_list	ap;

	va_start(ap, emsg);
	vlog(stderr, LOG_CRIT, emsg, ap);
	va_end(ap);
}

void printflike1
log_info(const char *emsg, ...)
{
	va_list	ap;

	if (conf.quiet)
		return;

	va_start(ap, emsg);
	vlog(stdout, LOG_INFO, emsg, ap);
	va_end(ap);
}

void printflike1
log_debug(const char *emsg, ...)
{
	va_list	ap;

	if (conf.debug > 0) {
		va_start(ap, emsg);
		vlog(stderr, LOG_DEBUG, emsg, ap);
		va_end(ap);
	}
}

void printflike1
log_debug2(const char *emsg, ...)
{
	va_list	ap;

	if (conf.debug > 1) {
		va_start(ap, emsg);
		vlog(stderr, LOG_DEBUG, emsg, ap);
		va_end(ap);
	}
}

void printflike1
log_debug3(const char *emsg, ...)
{
	va_list	ap;

	if (conf.debug > 2) {
		va_start(ap, emsg);
		vlog(stderr, LOG_DEBUG, emsg, ap);
		va_end(ap);
	}
}

__dead void
fatal(const char *emsg)
{
	if (emsg == NULL)
		logit(LOG_CRIT, "fatal: %s", strerror(errno));
	else
		if (errno)
			logit(LOG_CRIT, "fatal: %s: %s", emsg, strerror(errno));
		else
			logit(LOG_CRIT, "fatal: %s", emsg);

	exit(1);
}

__dead void
fatalx(const char *emsg)
{
	errno = 0;
	fatal(emsg);
}
